#!/bin/bash
#
# File: CompressRandom.sh
# Author: Keith Schwarz (htiek@cs.stanford.edu)
#
# A program that generates a file of random bytes and
# compresses it with a bunch of different compression utilities.

# Remove any old files.
rm -f archive.zip archive.tar archive.gz random.file.bz2 random.file archive.7z random.file.xz random.file.lzo random.file.rz

# Thanks to http://tiagoferreira.nome.pt/blog/archives/5 for this line,
# which pulls blocks of random data from /dev/urandom into a file.
dd if=/dev/urandom of=random.file bs=1K count=128 2> /dev/null

# Compress the random file with zip
zip archive.zip random.file > /dev/null

# Compress the file with bzip2
bzip2 -k random.file

# Compress the file with gzip
gzip -c random.file > archive.gz

# Compress the file with 7z
7za a -t7z archive.7z random.file > /dev/null

# Compress the file with xz
xz -zk random.file

# Compress the file with lzop
lzop random.file

# Compress the file with rzip
rzip -k random.file

# Compare file sizes
orig=`wc -c random.file | sed s/random.file//`
zipS=`wc -c archive.zip | sed s/archive.zip//`
bzip2S=`wc -c random.file.bz2 | sed s/random.file.bz2//`
gzipS=`wc -c archive.gz | sed s/archive.gz//`
sevenzS=`wc -c archive.7z | sed s/archive.7z//`
xzS=`wc -c random.file.xz | sed s/random.file.xz//`
lzopS=`wc -c random.file.lzo | sed s/random.file.lzo//`
rzipS=`wc -c random.file.rz | sed s/random.file.rz//`

# Clear the display so that we can run repeatedly.
clear

echo "Total number of random bytes: " $orig
echo "Size, compressed with zip:    " $zipS "(" `echo "scale = 4; $zipS / $orig * 100" | bc` "% )"
echo "Size, compressed with bzip2:  " $bzip2S "(" `echo "scale = 4; $bzip2S / $orig * 100" | bc` "% )"
echo "Size, compressed with gzip:   " $gzipS "(" `echo "scale = 4; $gzipS / $orig * 100" | bc` "% )"
echo "Size, compressed with 7z:     " $sevenzS "(" `echo "scale = 4; $sevenzS / $orig * 100" | bc` "% )"
echo "Size, compressed with xz:     " $xzS "(" `echo "scale = 4; $xzS / $orig * 100" | bc` "% )"
echo "Size, compressed with lzop:   " $lzopS "(" `echo "scale = 4; $lzopS / $orig * 100" | bc` "% )"
echo "Size, compressed with rzip:   " $rzipS "(" `echo "scale = 4; $rzipS / $orig * 100" | bc` "% )"
